MessageMarquee class

跑马灯配置

Constructors

MessageMarquee({int? speed, int? loop, int? delay})

Properties

delay int?
延迟时间(毫秒)
final
hashCode int
The hash code for this object.
no setterinherited
loop int?
循环次数
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed int?
速度
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited