TDBottomTabBarIndicatorAnimation enum
Values
- none → const TDBottomTabBarIndicatorAnimation
-
无动画,瞬间切换
- linear → const TDBottomTabBarIndicatorAnimation
-
线性滑动:指示器匀速从一个 tab 滑到另一个
- elastic → const TDBottomTabBarIndicatorAnimation
-
弹性动画:指示器先拉伸后收缩
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TDBottomTabBarIndicatorAnimation> - A constant List of the values in this enum, in order of their declaration.