TDInputDialog class

带有输入框的弹窗

Inheritance

Constructors

TDInputDialog({Key? key, required TextEditingController textEditingController, Color? backgroundColor, double radius = 12.0, String? title, Color? titleColor, AlignmentGeometry? titleAlignment, Widget? contentWidget, String? content, String? hintText = '', Color? contentColor, TDDialogButtonOptions? leftBtn, TDDialogButtonOptions? rightBtn, bool? showCloseButton, EdgeInsets? padding = const EdgeInsets.fromLTRB(24, 32, 24, 0), Widget? buttonWidget, Widget? customInputWidget})
const

Properties

backgroundColor Color?
背景颜色
final
buttonWidget Widget?
自定义按钮
final
content String?
内容
final
contentColor Color?
内容颜色
final
contentWidget Widget?
内容Widget
final
customInputWidget Widget?
自定义输入框
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
输入提示
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftBtn TDDialogButtonOptions?
左侧按钮配置
final
padding EdgeInsets?
内容内边距
final
radius double
圆角
final
rightBtn TDDialogButtonOptions?
右侧按钮配置
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool?
显示右上角关闭按钮
final
textEditingController TextEditingController
输入controller
final
title String?
标题
final
titleAlignment AlignmentGeometry?
标题对齐模式
final
titleColor Color?
标题颜色
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited