TDProgress class

Inheritance

Constructors

TDProgress({Key? key, required TDProgressType type, double? value, TDLabelWidget? label, TDProgressStatus progressStatus = TDProgressStatus.primary, TDProgressLabelPosition progressLabelPosition = TDProgressLabelPosition.inside, double? strokeWidth, Color? color, Color? backgroundColor, BorderRadiusGeometry? linearBorderRadius, double? circleRadius, bool showLabel = true, Widget? customProgressLabel, double? labelWidgetWidth, Alignment? labelWidgetAlignment, VoidCallback? onTap, VoidCallback? onLongPress, int animationDuration = 300})

Properties

animationDuration int?
动画持续时间(正整数,单位为毫秒)
final
backgroundColor Color?
进度条背景颜色
final
circleRadius double?
环形进度条半径(正数)
final
color Color?
进度条颜色
final
customProgressLabel Widget?
自定义标签
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label TDLabelWidget?
进度条标签
final
labelWidgetAlignment Alignment?
自定义标签对齐方式
final
labelWidgetWidth double?
自定义标签宽度
final
linearBorderRadius BorderRadiusGeometry?
条形进度条末端形状
final
onLongPress VoidCallback?
长按事件
final
onTap VoidCallback?
点击事件
final
progressLabelPosition TDProgressLabelPosition
标签显示位置
final
progressStatus TDProgressStatus
进度条状态
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabel bool
是否显示标签
final
strokeWidth double?
进度条粗细(正数)
final
type TDProgressType
进度条类型
final
value double?
进度值(0.0 到 1.0 之间的正数)
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited