TDSideBarItem class

Constructors

TDSideBarItem({Key? key, TDBadge? badge, bool disabled = false, IconData? icon, TextStyle? textStyle, String label = '', int value = -1})
const

Properties

badge TDBadge?
徽标
final
disabled bool
是否禁用
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
图标
final
label String
标签
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
标签样式
final
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited