TDStepsItemData class
Steps步骤条数据类型
Constructors
Properties
- content → String?
-
内容
final
- customContent → Widget?
-
自定义内容
final
- customTitle → Widget?
-
自定义标题
final
- errorIcon → IconData?
-
失败图标
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successIcon → IconData?
-
成功图标
final
- title → String?
-
标题
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited